@@ -1,9 +1,6 @@
 import warnings
 import numpy as np
-import os
 import h5py as h5
-import tables as tb
-import glob
 
 from tornado.ioloop import PeriodicCallback
 
@@ -17,18 +14,15 @@ from matplotlib.colors import LogNorm, Normalize
 from mpl_toolkits.axes_grid1.axes_divider import make_axes_locatable
 
 import ipywidgets as widgets
-from ipywidgets import interact, Button, Layout, interactive, fixed
-from IPython.display import Markdown, Latex, clear_output
+from ipywidgets import interact, fixed
 from IPython.core.display import display, HTML
 import ipyvolume as ipv
 
-from bokeh.plotting import figure, show, output_file
-from bokeh.layouts import row, column
+from bokeh.plotting import figure
+from bokeh.layouts import row
 from bokeh.io import output_notebook
-from bokeh.models import ColumnDataSource, ColorBar, LogColorMapper, LinearColorMapper
-from bokeh.models import BoxEditTool, HoverTool, CrosshairTool, LassoSelectTool
-from bokeh.models import CustomJS, Slider, SaveTool, Select, RadioButtonGroup
-from bokeh.models.widgets import Tabs, Panel
+from bokeh.models import ColumnDataSource, ColorBar, LinearColorMapper
+from bokeh.models import Slider, RadioButtonGroup
 import bokeh.palettes as bp
 import panel as pn
 pn.extension()
@@ -44,11 +38,10 @@ class Plotter:
 
     def __init__(
         self,
-        filename=None,
-        data_array=None,
+        data,
         plot="slices",
         log=False,
-        cmap="YlGnBu_r",
+        cmap="turbo",
         figsize=(10, 10),
         fontsize=15,
         title=None,
@@ -69,8 +62,8 @@ class Plotter:
         :param figsize: default (10, 10)
         :param fontsize: default 15
         """
-        self.filename = filename
-        self.data_array = data_array
+        self.filename = None
+        self.data_array = None
         self.plot = plot
         self.log = log
         self.cmap = cmap
@@ -82,10 +75,12 @@ class Plotter:
         self.interact_scale = False
 
         # Get data array from any of the supported files
-        if isinstance(filename, str) and not data_array:
+        if isinstance(data, str):
+            self.filename = data
             self.get_data_array()
 
-        elif isinstance(data_array, np.ndarray) and not filename:
+        elif isinstance(data, np.ndarray):
+            self.data_array = data
             # Plot data
             if self.plot == "2D":
                 self.plot_data(figsize=self.figsize, fontsize=self.fontsize,
@@ -106,7 +101,7 @@ class Plotter:
                     f"\tNb of dimensions: {self.data_array.ndim}\n"
                     f"\tShape: {self.data_array.shape}\n"
                     "\t'plot' keyword accepted values: ('2D', 'slices', 3D')"
-                    "#########################################################"
+                    "\n#########################################################"
                     "########################################################"
                 )
 
@@ -188,7 +183,7 @@ class Plotter:
                     f"\tNb of dimensions: {self.data_array.ndim}\n"
                     f"\tShape: {self.data_array.shape}\n"
                     "\t'plot' keyword accepted values: ('2D', 'slices', 3D')"
-                    "#########################################################"
+                    "\n#########################################################"
                     "########################################################"
                 )
 
@@ -363,70 +358,6 @@ class ThreeDViewer(widgets.Box):
             readout=True
         )
 
-        # Plane widgets
-        self.toggle_plane = widgets.ToggleButton(
-            value=False,
-            description='Cut planes',
-            tooltips='Cut plane'
-        )
-        self.plane_text = widgets.Text(
-            value="",
-            description="",
-            tooltips='Plane equation')
-        hbox_plane = widgets.HBox([self.toggle_plane, self.plane_text])
-
-        # Clip widgets
-        self.clipx = widgets.FloatSlider(
-            value=1,
-            min=-1,
-            max=1,
-            step=0.1,
-            description='Plane Ux',
-            disabled=False,
-            continuous_update=False,
-            orientation='horizontal',
-            readout=True,
-            readout_format='.01f',
-        )
-        self.clipy = widgets.FloatSlider(
-            value=1,
-            min=-1,
-            max=1,
-            step=0.1,
-            description='Plane Uy',
-            disabled=False,
-            continuous_update=False,
-            orientation='horizontal',
-            readout=True,
-            readout_format='.01f',
-        )
-        self.clipz = widgets.FloatSlider(
-            value=1,
-            min=-1,
-            max=1,
-            step=0.1,
-            description='Plane Uz',
-            disabled=False,
-            continuous_update=False,
-            orientation='horizontal',
-            readout=True,
-            readout_format='.01f',
-        )
-        self.clipdist = widgets.FloatRangeSlider(
-            value=[0, 100],
-            min=0,
-            max=100,
-            step=0.5,
-            description='Planes dist',
-            disabled=False,
-            continuous_update=False,
-            orientation='horizontal',
-            readout=True,
-            readout_format='.1f',
-        )
-
-        # self.toggle_mode = widgets.ToggleButtons(options=['Volume','X','Y','Z'])
-
         # Progress bar
         self.progress = widgets.IntProgress(
             value=10,
@@ -443,11 +374,6 @@ class ThreeDViewer(widgets.Box):
         self.toggle_phase.observe(self.on_change_scale)
         self.colormap.observe(self.on_update_plot)
         self.colormap_range.observe(self.on_update_plot)
-        self.clipx.observe(self.on_update_plot)
-        self.clipy.observe(self.on_update_plot)
-        self.clipz.observe(self.on_update_plot)
-        self.clipdist.observe(self.on_update_plot)
-        self.toggle_plane.observe(self.on_update_plot)
 
         self.toggle_dark.observe(self.on_update_style)
         self.toggle_box.observe(self.on_update_style)
@@ -465,32 +391,17 @@ class ThreeDViewer(widgets.Box):
         self.vbox = widgets.VBox([self.threshold,
                                   hbox1, hbox_toggle,
                                   self.colormap,
-                                  # self.colormap_range,
-                                  # hbox_plane,
-                                  # self.clipx, self.clipy, self.clipz,
-                                  # self.clipdist,
+                                  # self.colormap_range, # useless for one contour
                                   self.progress,
-                                  # self.fc
                                   ])
 
         # Load data
         if isinstance(input_file, np.ndarray):
-            data_array = input_file
-
             # We create an output for ipyvolume
             self.output_view = widgets.Output()
             with self.output_view:
-                self.fig = ipv.figure(
-                    # width=900,
-                    # height=600,
-                    # controls_light=True,
-                )
-                # if input_file is not None:
-                #     if isinstance(input_file, str):
-                #         if os.path.isfile(input_file):
-                #             self.change_file(input_file)
-                #     elif isinstance(input_file, np.ndarray):
-                self.set_data(d=data_array)
+                self.fig = ipv.figure()
+                self.set_data(input_file)
                 display(self.fig)
 
             self.window = widgets.HBox([self.output_view, self.vbox])
@@ -510,63 +421,9 @@ class ThreeDViewer(widgets.Box):
             return
         self.progress.value = 7
 
-        # See https://github.com/maartenbreddels/ipyvolume/issues/174
-        # to support using normals
-
-        # Unobserve as we disable/enable buttons and that triggers events
-        # try:
-        #     self.clipx.unobserve(self.on_update_plot)
-        #     self.clipy.unobserve(self.on_update_plot)
-        #     self.clipz.unobserve(self.on_update_plot)
-        #     self.clipdist.unobserve(self.on_update_plot)
-        # except:
-        #     pass
-
-        # if self.toggle_plane.value:
-        #     self.clipx.disabled = False
-        #     self.clipy.disabled = False
-        #     self.clipz.disabled = False
-        #     self.clipdist.disabled = False
-        #     # Cut volume with clipping plane
-        #     uz, uy, ux = self.clipz.value, self.clipy.value, self.clipx.value
-        #     u = np.sqrt(ux ** 2 + uy ** 2 + uz ** 2)
-        #     if np.isclose(u, 0):
-        #         ux = 1
-        #         u = 1
-
-        #     nz, ny, nx = self.d.shape
-        #     z, y, x = np.meshgrid(np.arange(nz), np.arange(
-        #         ny), np.arange(nx), indexing='ij')
-
-        #     # Compute maximum range of clip planes & fix dist range
-        #     tmpz, tmpy, tmpx = np.where(abs(self.d) >= self.threshold.value)
-        #     tmp = (tmpx * ux + tmpy * uy + tmpz * uz) / u
-        #     tmpmin, tmpmax = tmp.min() - 1, tmp.max() + 1
-        #     if tmpmax > self.clipdist.min:  # will throw an exception if min>max
-        #         self.clipdist.max = tmpmax
-        #         self.clipdist.min = tmpmin
-        #     else:
-        #         self.clipdist.min = tmpmin
-        #         self.clipdist.max = tmpmax
-
-        #     # Compute clipping mask
-        #     c = ((x * ux + y * uy + z * uz) / u > self.clipdist.value[0]) * (
-        #         ((x * ux + y * uy + z * uz) / u < self.clipdist.value[1]))
-        #     self.plane_text.value = "%6.1f < (%4.2f*x %+4.2f*y %+4.2f*z) < %6.1f" % (
-        #         self.clipdist.value[0], ux / u, uy / u,
-        #         uz / u, self.clipdist.value[1])
-        # else:
-        #     self.clipx.disabled = True
-        #     self.clipy.disabled = True
-        #     self.clipz.disabled = True
-        #     self.clipdist.disabled = True
-        #     self.plane_text.value = ""
-        #     c = 1
-
-        c = 1
         try:
             verts, faces, _, _ = marching_cubes(
-                abs(self.d) * c,
+                abs(self.d),
                 level=self.threshold.value,
                 step_size=1,
             )
@@ -605,15 +462,6 @@ class ThreeDViewer(widgets.Box):
         except Exception as E:
             print(E)
 
-        # Observe again
-        # try:
-        #     self.clipx.observe(self.on_update_plot)
-        #     self.clipy.observe(self.on_update_plot)
-        #     self.clipz.observe(self.on_update_plot)
-        #     self.clipdist.observe(self.on_update_plot)
-        # except:
-        #     pass
-
         # Update progress bar
         self.progress.value = 10
 
@@ -643,40 +491,6 @@ class ThreeDViewer(widgets.Box):
             else:
                 ipv.pylab.style.axes_off()
 
-    # def on_select_file(self, change):
-    #     """
-    #     Called when a file selection has been done
-    #     :param change:
-    #     :return:
-    #     """
-    #     self.change_file(self.fc.selected)
-
-    # def change_file(self, file_name):
-    #     """
-    #     Function used to load data from a new file
-    #     :param file_name: the file where the object data is loaded,
-    #      either a CXI or modes h5 file
-    #     :return:
-    #     """
-    #     self.progress.value = 3
-    #     print('Loading:', file_name)
-
-    #     try:
-    #         self.toggle_plane.unobserve(self.on_update_plot)
-    #         self.toggle_plane.value = False
-    #         self.toggle_plane.observe(self.on_update_plot)
-    #         d = h5.File(file_name, mode='r')['entry_1/data_1/data'][()]
-    #         if d.ndim == 4:
-    #             d = d[0]
-    #         d = np.swapaxes(d, 0, 2)  # Due to labelling of axes x,y,z and not z,y,x
-    #         if 'log' in self.toggle_phase.value:
-    #             self.d0 = d
-    #             d = np.log10(np.maximum(0.1, abs(d)))
-    #         self.set_data(d)
-    #     except:
-    #         print("Failed to load file - is this a \
-    #               result CXI result or a modes file from a 3D CDI analysis ?")
-
     def on_change_scale(self, change):
         """Change scale between logarithmic and linear"""
         if change['name'] == 'value':
@@ -738,7 +552,6 @@ class ThreeDViewer(widgets.Box):
         self.threshold.observe(self.on_update_plot)
         self.colormap_range.observe(self.on_update_plot)
 
-        # print(abs(self.d).max(), self.threshold.value)
         nz, ny, nx = self.d.shape
         z, y, x = np.arange(nz), np.arange(ny), np.arange(nx)
 
@@ -773,7 +586,7 @@ class ThreeDViewer(widgets.Box):
         ipv.squarelim()
         self.on_update_plot()
 
-    def on_animate(self):
+    def on_animate(self, v):
         """Trigger the animation (rotation around vertical axis)
         """
         if self.pcb_rotate is None:
@@ -805,7 +618,7 @@ def plot_data(
     figsize=(10, 10),
     fontsize=15,
     log="interact",
-    cmap="YlGnBu_r",
+    cmap="turbo",
     title=None,
 ):
     """
@@ -853,7 +666,6 @@ def plot_data(
                 # Create figure
                 if not figsize:
                     figsize = (7, 7)
-                    print("Figure size defaulted to", figsize)
 
                 _, ax = plt.subplots(figsize=figsize)
 
@@ -880,7 +692,7 @@ def plot_data(
                 position='right', size='5%', pad=0.1)
 
             # Create colorbar
-            cbar = fig.colorbar(mappable=img, cax=cbar_ax)
+            fig.colorbar(mappable=img, cax=cbar_ax)
 
             # Show figure
             plt.tight_layout()
@@ -900,7 +712,6 @@ def plot_data(
                 # Create figure
                 if not figsize:
                     figsize = (10, 10)
-                    print("Figure size defaulted to", figsize)
 
                 fig, ax = plt.subplots(figsize=figsize)
 
@@ -916,7 +727,7 @@ def plot_data(
                     position='right', size='5%', pad=0.1)
 
                 # Create colorbar
-                cbar = fig.colorbar(mappable=img, cax=cbar_ax)
+                fig.colorbar(mappable=img, cax=cbar_ax)
 
                 # Show figure
                 plt.tight_layout()
@@ -924,6 +735,7 @@ def plot_data(
 
     elif data_dimensions == 3:
 
+        # Define function used to get data slice
         def get_data_slice(
             data,
             axis="x",
@@ -931,6 +743,18 @@ def plot_data(
             data_type="Module",
             scale="linear",
         ):
+            """
+            Function used when using widgets with callbacks
+            on the 3D image
+
+            :param data: 3D data array
+            :param axis: axis on which the data is projected
+             in ("x", "y", "z")
+            :param index: index along param axis
+            :param data_type: plot module, phase,
+             real or imaginary part of the data
+            :param scale: log or lin
+            """
             # Project on specific index
             if axis == "x":
                 dt = data[index, :, :]
@@ -1025,7 +849,7 @@ def plot_data(
             value=0,
             step=1,
             title="Position",
-            orientation = "vertical",
+            orientation="horizontal",
         )
         slider_index.on_change('value', callback_change_index)
 
@@ -1051,17 +875,17 @@ def plot_data(
 
             # Get new axis names and slider range
             if new_axis == "x":
-                slider_range = data.shape[0]
+                slider_range = data_array.shape[0]
                 fig.axis[0].axis_label = "y"
                 fig.axis[1].axis_label = "z"
 
             elif new_axis == "y":
-                slider_range = data.shape[1]
+                slider_range = data_array.shape[1]
                 fig.axis[0].axis_label = "x"
                 fig.axis[1].axis_label = "z"
 
             elif new_axis == "z":
-                slider_range = data.shape[2]
+                slider_range = data_array.shape[2]
                 fig.axis[0].axis_label = "x"
                 fig.axis[1].axis_label = "y"
 
@@ -1142,7 +966,7 @@ def plot_data(
         fig.add_layout(lin_color_bar, 'right')
 
         # Image
-        image = fig.image(
+        fig.image(
             image="data",
             source=source,
             x=0,
@@ -1180,7 +1004,7 @@ def plot_2d_image(
     fig=None,
     ax=None,
     log=False,
-    cmap="YlGnBu_r",
+    cmap="turbo",
     title=None,
     x_label="x",
     y_label="y"
@@ -1198,7 +1022,6 @@ def plot_2d_image(
     :param title: str, title for this axe
     :return: image on ax (ax.imshow())
     """
-
     if not fig and not ax:
         fig, ax = plt.subplots(1, 1, figsize=(5, 5))
 
@@ -1248,8 +1071,8 @@ def plot_3d_slices(
     fontsize=15,
     figsize=None,
     log=False,
-    cmap="YlGnBu_r",
-    title=None
+    cmap="turbo",
+    title=None,
 ):
     """
     Plot 3 slices for 3d data.
@@ -1267,13 +1090,12 @@ def plot_3d_slices(
         # Create figure
         if not figsize:
             figsize = (15, 7)
-            print("Figure size defaulted to", figsize)
 
         fig, axs = plt.subplots(1, 3, figsize=figsize)
 
         # Add titles
         if isinstance(title, str):
-            fig.suptitle(title, fontsize=fontsize + 2)
+            fig.suptitle(title, fontsize=fontsize + 2, y=0.95)
             titles = [None, None, None]
         elif isinstance(title, tuple) and len(title) == 3 or isinstance(title, list) and len(title) == 3:
             titles = title
@@ -1325,7 +1147,6 @@ def plot_3d_slices(
         # Show figure
         fig.tight_layout()
         fig.show()
-        # plt.close()
 
     else:
         @interact(
@@ -1341,7 +1162,6 @@ def plot_3d_slices(
             # Create figure
             if not figsize:
                 figsize = (15, 7)
-                print("Figure size defaulted to", figsize)
 
             fig, axs = plt.subplots(1, 3, figsize=figsize)
 
